| ccm_distributions | R Documentation |
Details on the probability distributions implemented in the CCMnet. These distributions define the target distribution placed on network properties during the MCMC sampling process.
By decoupling the probability distribution from the network property,
CCMnet allows researchers to represent structural uncertainty. For
example, one might target a specific degree distribution via "dirmult"
while allowing the total edge count to follow a wide "gamma" distribution.
"poisson"Requires list(lambda). Typically used for
count-based statistics like "edges" or "triangles".
"gamma"Requires list(shape, rate). Useful for
continuous or skewed properties. The implementation uses the kernel
x^{\alpha-1}e^{-\beta x}.
"dirmult"Requires list(alphas). A Dirichlet-Multinomial
implementation optimized for proportions. In CCMnet, the global
normalizing constant is omitted to facilitate sampling in systems where
the total count (e.g., total edges) is variable.
"normal"Requires list(mean, sd). Standard Gaussian
constraint.
"lognormal"Requires list(log mean, log sd). Log-scale
of standard Gaussian constraint.
"beta"Requires list(shape1, shape2). Restricted to
properties bounded in the interval [0,1], such as "density".
"uniform"A flat distribution where the MCMC explores the congruence class without preference for specific statistic values.
ccm_properties, sample_ccm
Other ccm_core:
ccm_properties,
sample_ccm()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.