| ccm_properties | R Documentation |
CCMnet implements a systematic hierarchy of network properties motivated by the dk-series framework (Mahadevan et al., 2006; Orsini et al., 2015). These properties can be targeted using soft constraints governed by user-specified probability distributions.
The following properties follow the dk-series framework, which defines increasingly constrained random graph ensembles:
"edges" (0k)The total number of edges within the graph. This is the simplest topological constraint.
"degreedist" (1k)A vector where the j-th entry represents the number of nodes having degree j.
"degmixing" (2k)The joint degree distribution, represented as a degree mixing matrix. The (i,j) entry represents the number of edges between nodes with degree i and degree j, capturing degree-degree correlations (degree assortativity).
"degmixing" + "triangles" (2.1k)Extends the 2k distribution by including the total number of closed triads (triangles) in the network, allowing for clustering constraints.
CCMnet incorporates node-level attributes by defining congruence classes based on categorical or discretized covariates (e.g., homophily or social stratification).
"mixing"The attribute mixing matrix. The (i,j) entry
represents the number of edges between nodes belonging to covariate groups
$i$ and $j$. Requires cov_pattern.
"degreedist+degreedist+mixing"A combination property that includes the attribute mixing matrix alongside separate degree distributions calculated for each distinct covariate group. Currently on a binary covariate is implemented. Therefore, input is characteristics for two degree distributions and one scalar mixing value.
Mahadevan, P., Krioukov, D., Fomenkov, K., Huffaker, B., & Vahdat, A. (2006). Systematic topology analysis and generation using degree correlations. ACM SIGCOMM Computer Communication Review.
Orsini, C., et al. (2015). Quantifying randomness in real networks. Nature Communications.
ccm_distributions, sample_ccm
Other ccm_core:
ccm_distributions,
sample_ccm()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.