View source: R/CCMnet_Sample_methods.R
| plot.ccm_sample | R Documentation |
Printing, summarizing, and plotting methods for results generated by sample_ccm.
## S3 method for class 'ccm_sample'
plot(
x,
stats = NULL,
type = c("density", "hist", "trace"),
include_theoretical = FALSE,
...
)
## S3 method for class 'ccm_sample'
print(x, ...)
## S3 method for class 'ccm_sample'
summary(object, ...)
x, object |
An object of class |
stats |
Character vector of statistic names to plot. If |
type |
Character string specifying the plot type: |
include_theoretical |
Logical. If |
... |
Additional arguments passed to methods. |
For type = "trace", setting include_theoretical = TRUE adds a
red dashed line for the theoretical mean and red dotted lines for the
2.5% and 97.5% quantiles.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.